@@ -22,4 +22,4 @@ class TestTools(unittest.TestCase):
         create_article('生日快乐', line_num=2000)
 
     def test_pwd4wifi(self):
-        pwd4wifi()
+        pwd4wifi(pwd_list=['12345678', 'Ykzs2020'])
